@@ -43,7 +43,7 @@ impl Client {
 	async fn get(&self, t: &str, mut qparams: BTreeMap<&str, SmartCow<'_>>) -> Result<Bytes, reqwest::Error> {
 		qparams.insert("apikey", SmartCow::Borrowed(&self.apikey));
 		let url = format!("{}?t={}&{}", self.base_url, &t, qparams.into_iter()
-			.map(|(k, v)| format!("{}={}", urlencoding::encode(&k), urlencoding::encode(&v)).into())
+			.map(|(k, v)| format!("{}={}", urlencoding::encode(k), urlencoding::encode(&v)).into())
 			.collect::<Vec<String>>()
 			.join("&")
 		);
